﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Infragistics.Web.UI.GridControls;

public partial class _Default : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        this.WebHierarchicalDataGrid1.DataSource = CreateDataSet();
    }

    protected void button_click(object sender, EventArgs e)
    {
        selection.InnerHtml = "";
        GetContainerGrid(WebHierarchicalDataGrid1.GridView);
    }

    protected void GetContainerGrid(ContainerGrid gridView)
    {
        if (gridView.Level == 0)
            GetSelectedRows(gridView);

        for (int i = 0; i < gridView.Rows.Count; i++)
        {
            ContainerGridRecord record = (ContainerGridRecord)gridView.Rows[i];

            if (record.HasRowIslands)
            {
                ContainerGrid containerGrid = record.RowIslands[0];
                GetSelectedRows(containerGrid);
                GetContainerGrid(containerGrid);
            }
        }
    }
    protected void GetSelectedRows(ContainerGrid gridView)
    {

        SelectedRowCollection rows = gridView.Behaviors.Selection.SelectedRows;
        for (int i = 0; i < rows.Count; i++)
        {
            if (gridView.Level == 0)
                selection.InnerHtml += rows[i].Items[1].Text + "<br/>";
            else
                selection.InnerHtml += rows[i].Items[2].Text + "<br/>";
        }
    }

    #region DataSource

    private DataSet CreateDataSet()
    {
        DataSet ds = new DataSet();

        ds.Tables.Add(Actors());
        ds.Tables.Add(Movies());
        ds.Tables.Add(SoundTracks());


        DataRelation actorID = new DataRelation("actorID", ds.Tables["Actors"].Columns["ActorID"], ds.Tables["Movies"].Columns["ActorID"]);
        ds.Relations.Add(actorID);
        DataRelation movieID = new DataRelation("movieID", ds.Tables["Movies"].Columns["MovieID"], ds.Tables["SoundTracks"].Columns["MovieID"]);
        ds.Relations.Add(movieID);

        return ds;
    }

    private DataTable Actors()
    {
        DataTable actors = new DataTable("Actors");
        DataColumn primaryKey = new DataColumn("ActorID");
        primaryKey.DataType = System.Type.GetType("System.Int32");
        primaryKey.AutoIncrement = true;
        actors.Columns.Add(primaryKey);
        actors.PrimaryKey = new DataColumn[] { primaryKey };
        actors.Columns.Add("Name", System.Type.GetType("System.String"));
        FillActors(actors);
        return actors;
    }

    private DataTable Movies()
    {
        DataTable movies = new DataTable("Movies");
        DataColumn primaryKey = new DataColumn("MovieID");
        primaryKey.DataType = System.Type.GetType("System.Int32");
        primaryKey.AutoIncrement = true;
        movies.Columns.Add(primaryKey);
        movies.Columns.Add("ActorID", System.Type.GetType("System.Int32"));
        movies.Columns.Add("Title", System.Type.GetType("System.String"));
        movies.Columns.Add("Year", System.Type.GetType("System.Int32"));
        movies.PrimaryKey = new DataColumn[] { primaryKey };
        FillMovies(movies);
        return movies;
    }

    private DataTable SoundTracks()
    {
        DataTable soundTracks = new DataTable("SoundTracks");
        DataColumn primaryKey = new DataColumn("SoundTrackID");
        primaryKey.DataType = System.Type.GetType("System.Int32");
        primaryKey.AutoIncrement = true;
        soundTracks.Columns.Add(primaryKey);
        soundTracks.Columns.Add("MovieID", System.Type.GetType("System.Int32"));
        soundTracks.Columns.Add("Song", System.Type.GetType("System.String"));
        soundTracks.Columns.Add("Singer", System.Type.GetType("System.String"));
        soundTracks.PrimaryKey = new DataColumn[] { primaryKey };
        FillSoundTrack(soundTracks);
        return soundTracks;

    }

    private void FillSoundTrack(DataTable soundTracks)
    {
        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 0, "Safe and Sound", "Sheryl Crow"));
        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 0, "Rocket Man", "Elton John"));

        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 1, "Because", "Elliott Smith"));
        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 1, "Don't Rain On My Parade", "Bobby Darin"));

        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 2, "LE SONS ET LES PARFUMS TOURNENT DANS L'AIR DU SOIR", "Jon Kull"));
        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 2, "STEPPIN' OUT", "Paul Nelson"));

        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 3, "Warm It Up Kane", "Big Daddy Kane"));
        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 3, "Flava in Ya Ear", "Craig Mack"));

        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 4, "COFFEE STORE ZAK", "Rolfe Kent"));
        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 4, "GIRL FROM YPSILANTI", "Daniel May"));

        soundTracks.Rows.Add(CreateSoundTrackRow(soundTracks, 5, "Battle Hymn of the Republic", "William Steffe"));
    }

    private DataRow CreateSoundTrackRow(DataTable soundTracks, int movieID, string song, string singer)
    {
        DataRow soundTrackRow = soundTracks.NewRow();
        soundTrackRow["MovieID"] = movieID;
        soundTrackRow["Song"] = song;
        soundTrackRow["Singer"] = singer;
        return soundTrackRow;
    }

    private void FillActors(DataTable actors)
    {
        actors.Rows.Add(CreateActorRow(actors, "Kevin Spacey"));
        actors.Rows.Add(CreateActorRow(actors, "Edward Norton"));
    }

    private DataRow CreateActorRow(DataTable actors, string name)
    {
        DataRow actorRow = actors.NewRow();
        actorRow["Name"] = name;
        return actorRow;
    }

    private void FillMovies(DataTable movies)
    {
        movies.Rows.Add(CreateMoviesRow(movies, 0, "K-PAX", 2001));
        movies.Rows.Add(CreateMoviesRow(movies, 0, "American Beauty", 1999));
        movies.Rows.Add(CreateMoviesRow(movies, 0, "The Usual Suspects", 1995));
        movies.Rows.Add(CreateMoviesRow(movies, 1, "25th Hour", 2002));
        movies.Rows.Add(CreateMoviesRow(movies, 1, "Fight Club", 1999));
        movies.Rows.Add(CreateMoviesRow(movies, 1, "American History X", 1998));
    }


    private DataRow CreateMoviesRow(DataTable movies, int actorId, string title, int year)
    {
        DataRow movieRow = movies.NewRow();
        movieRow["ActorID"] = actorId;
        movieRow["Title"] = title;
        movieRow["Year"] = year;
        return movieRow;
    }
    #endregion
}
